@@ -7,17 +7,18 @@ import plotly.graph_objects as go
 import scipy
 import warnings
 
+
 class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
     def __init__(self,
                  objective_function,
-                 n_iteration: int = 1000,
+                 n_iteration: int = 20,
                  timeout: int = None,
                  population_size=50,
                  minimize=True,
                  c1=2,
                  c2=2,
-                 w=0.9):
-
+                 w=0.9,
+                 **kwargs):
         """       
         Parameters
         ----------
@@ -27,7 +28,7 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
         population_size: int, default=50
             Total size of the population , default=50
 
-        n_iteration: int, default=1000
+        n_iteration: int, default=20
             Number of time the Particle Swarm Optimization algorithm will run
 
         timeout: int = None
@@ -46,18 +47,21 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
         w: float, default=0.9
             Velocity weight factor
 
+        **kwargs
+            Any extra keyword argument for objective_function
+
         Attributes
         ----------
         best_feature_list : ndarray of shape (n_features)
             list of features with the best result of the entire run
         """
-        super().__init__(objective_function, n_iteration, timeout, population_size, minimize)
+        super().__init__(objective_function, n_iteration, timeout, population_size, minimize, **kwargs)
         self.c1 = c1
         self.c2 = c2
         self.w = w
 
-    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid,particle_swarm_flag=0,dragon_fly_flag=0):
-        return super()._evaluate_fitness(model, x_train, y_train, x_valid, y_valid,particle_swarm_flag,dragon_fly_flag)
+    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid, particle_swarm_flag=0, dragon_fly_flag=0):
+        return super()._evaluate_fitness(model, x_train, y_train, x_valid, y_valid, particle_swarm_flag, dragon_fly_flag)
 
     def fit(self, model, X_train, y_train, X_valid, y_valid, verbose=True):
         """
@@ -114,7 +118,7 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
             self._check_individuals()
 
             self.fitness_scores = self._evaluate_fitness(
-                model, X_train, y_train, X_valid, y_valid,1,0)
+                model, X_train, y_train, X_valid, y_valid, 1, 0)
 
             self.gbest_individual = self.best_dim
 
@@ -137,4 +141,3 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
             self.best_feature_list = list(
                 self.feature_list[np.where(self.best_dim)[0]])
         return self.best_feature_list
-
